==> carbon-component-mapper-3.9.0.tgz: package/esm/checkbox/checkbox.js <==
import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import MultipleChoiceListCommon from '@data-driven-forms/common/multiple-choice-list';
import CarbonCheckbox from "carbon-components-react/es/components/Checkbox/Checkbox.js";
import FormGroup from "carbon-components-react/es/components/FormGroup/FormGroup.js";
import WithDescription from '../with-description';
import prepareProps, { buildLabel } from '../prepare-props';
import HelperTextBlock from '../helper-text-block/helper-text-block';

var Wrapper = function Wrapper(_ref) {
  var label = _ref.label,
      description = _ref.description,
      children = _ref.children,
      helperText = _ref.helperText,
      error = _ref.error,
      showError = _ref.showError,
      isRequired = _ref.isRequired;
  return /*#__PURE__*/React.createElement(FormGroup, {
    legendText: description ? /*#__PURE__*/React.createElement(WithDescription, {
      labelText: buildLabel(label, isRequired),
      description: description
    }) : buildLabel(label, isRequired)
  }, children, /*#__PURE__*/React.createElement(HelperTextBlock, {
    helperText: helperText,
    errorText: showError && error
  }));
};

Wrapper.propTypes = {
  label: PropTypes.node,
  children: PropTypes.node,
  description: PropTypes.node,
  helperText: PropTypes.node,
  error: PropTypes.node,
  showError: PropTypes.bool,
  isRequired: PropTypes.bool
};

var SingleCheckbox = function SingleCheckbox(props) {
  var _useFieldApi = useFieldApi(prepareProps(_objectSpread(_objectSpread({}, props), {}, {
    type: 'checkbox'
  }))),
      input = _useFieldApi.input,
      meta = _useFieldApi.meta,
      validateOnMount = _useFieldApi.validateOnMount,
      helperText = _useFieldApi.helperText,
      WrapperProps = _useFieldApi.WrapperProps,
      rest = _objectWithoutProperties(_useFieldApi, ["input", "meta", "validateOnMount", "helperText", "WrapperProps"]);

  var invalid = (meta.touched || validateOnMount) && (meta.error || meta.submitError);
  var warnText = (meta.touched || validateOnMount) && meta.warning;
  return /*#__PURE__*/React.createElement("div", WrapperProps, /*#__PURE__*/React.createElement(CarbonCheckbox, _extends({}, input, {
    id: input.name
  }, rest)), /*#__PURE__*/React.createElement(HelperTextBlock, {
    helperText: helperText,
    errorText: invalid,
    warnText: warnText
  }));
};

var SingleCheckboxInCommon = function SingleCheckboxInCommon(_ref2) {
  var label = _ref2.label,
      isDisabled = _ref2.isDisabled,
      id = _ref2.id,
      props = _objectWithoutProperties(_ref2, ["label", "isDisabled", "id"]);

  return /*#__PURE__*/React.createElement(CarbonCheckbox, {
    id: id,
    labelText: label,
    disabled: isDisabled
  });
};

SingleCheckboxInCommon.propTypes = {
  label: PropTypes.node,
  input: PropTypes.object,
  isDisabled: PropTypes.bool,
  isRequired: PropTypes.bool,
  name: PropTypes.string,
  id: PropTypes.string,
  WrapperProps: PropTypes.object
};

var Checkbox = function Checkbox(_ref3) {
  var options = _ref3.options,
      props = _objectWithoutProperties(_ref3, ["options"]);

  return options ? /*#__PURE__*/React.createElement(MultipleChoiceListCommon, _extends({
    options: options
  }, props, {
    Wrapper: Wrapper,
    Checkbox: SingleCheckboxInCommon
  })) : /*#__PURE__*/React.createElement(SingleCheckbox, props);
};

Checkbox.propTypes = {
  options: PropTypes.arrayOf(PropTypes.shape({
    label: PropTypes.node,
    value: PropTypes.any
  }))
};
export default Checkbox;

==> carbon-component-mapper-3.11.4.tgz: package/esm/checkbox/checkbox.js <==
import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import MultipleChoiceListCommon from '@data-driven-forms/common/multiple-choice-list';
import CarbonCheckbox from "carbon-components-react/es/components/Checkbox/Checkbox.js";
import FormGroup from "carbon-components-react/es/components/FormGroup/FormGroup.js";
import WithDescription from '../with-description';
import prepareProps, { buildLabel } from '../prepare-props';
import HelperTextBlock from '../helper-text-block/helper-text-block';

var Wrapper = function Wrapper(_ref) {
  var label = _ref.label,
      description = _ref.description,
      children = _ref.children,
      helperText = _ref.helperText,
      error = _ref.error,
      showError = _ref.showError,
      isRequired = _ref.isRequired;
  return /*#__PURE__*/React.createElement(FormGroup, {
    legendText: description ? /*#__PURE__*/React.createElement(WithDescription, {
      labelText: buildLabel(label, isRequired),
      description: description
    }) : buildLabel(label, isRequired)
  }, children, /*#__PURE__*/React.createElement(HelperTextBlock, {
    helperText: helperText,
    errorText: showError && error
  }));
};

Wrapper.propTypes = {
  label: PropTypes.node,
  children: PropTypes.node,
  description: PropTypes.node,
  helperText: PropTypes.node,
  error: PropTypes.node,
  showError: PropTypes.bool,
  isRequired: PropTypes.bool
};

var SingleCheckbox = function SingleCheckbox(props) {
  var _useFieldApi = useFieldApi(prepareProps(_objectSpread(_objectSpread({}, props), {}, {
    type: 'checkbox'
  }))),
      input = _useFieldApi.input,
      meta = _useFieldApi.meta,
      validateOnMount = _useFieldApi.validateOnMount,
      helperText = _useFieldApi.helperText,
      WrapperProps = _useFieldApi.WrapperProps,
      rest = _objectWithoutProperties(_useFieldApi, ["input", "meta", "validateOnMount", "helperText", "WrapperProps"]);

  var invalid = (meta.touched || validateOnMount) && (meta.error || meta.submitError);
  var warnText = (meta.touched || validateOnMount) && meta.warning;
  return /*#__PURE__*/React.createElement("div", WrapperProps, /*#__PURE__*/React.createElement(CarbonCheckbox, _extends({}, input, {
    id: input.name
  }, rest)), /*#__PURE__*/React.createElement(HelperTextBlock, {
    helperText: helperText,
    errorText: invalid,
    warnText: warnText
  }));
};

var SingleCheckboxInCommon = function SingleCheckboxInCommon(_ref2) {
  var label = _ref2.label,
      isDisabled = _ref2.isDisabled,
      id = _ref2.id,
      meta = _ref2.meta,
      _ref2$option = _ref2.option,
      value = _ref2$option.value,
      name = _ref2$option.name,
      rest = _objectWithoutProperties(_ref2$option, ["value", "name"]),
      _onChange = _ref2.onChange,
      props = _objectWithoutProperties(_ref2, ["label", "isDisabled", "id", "meta", "option", "onChange"]);

  return /*#__PURE__*/React.createElement(CarbonCheckbox, _extends({
    id: id,
    labelText: label,
    disabled: isDisabled
  }, props, rest, {
    onChange: function onChange(_value, _name, event) {
      return _onChange(event);
    }
  }));
};

SingleCheckboxInCommon.propTypes = {
  label: PropTypes.node,
  input: PropTypes.object,
  isDisabled: PropTypes.bool,
  isRequired: PropTypes.bool,
  name: PropTypes.string,
  id: PropTypes.string,
  WrapperProps: PropTypes.object,
  meta: PropTypes.object,
  option: PropTypes.object,
  onChange: PropTypes.func
};

var Checkbox = function Checkbox(_ref3) {
  var options = _ref3.options,
      props = _objectWithoutProperties(_ref3, ["options"]);

  return options ? /*#__PURE__*/React.createElement(MultipleChoiceListCommon, _extends({
    options: options
  }, props, {
    Wrapper: Wrapper,
    Checkbox: SingleCheckboxInCommon
  })) : /*#__PURE__*/React.createElement(SingleCheckbox, props);
};

Checkbox.propTypes = {
  options: PropTypes.arrayOf(PropTypes.shape({
    label: PropTypes.node,
    value: PropTypes.any
  }))
};
export default Checkbox;
